function [u]=shk4a(neqn,t0,tf,u0,nsteps)
%
% Function shk4a computes an ODE solution by the fixed 
% step SHK method for a series of points along the 
% solution by repeatedly calling function ssshk4 for 
% a single shk4 step.
%
% Argument list
%
%   neqn     number of first order ODEs
%
%   t0       initial value of independent variable
%
%   tf       final value of independent variable
%
%   u0       initial condition vector of length neqn
%
%   nsteps   number of shk4 steps
%
%   u        ODE solution vector of length neqn after
%            nsteps steps
%
% Integration step
  h=(tf-t0)/nsteps;
%
% nsteps shk4 steps
  for i=1:nsteps
%
%   shk4 step
    [t,u,e]=ssshk4(neqn,t0,u0,h);
%
%   Reset base point values for next shk4 step
    u0=u;
    t0=t;
%
% Next shk4 step
  end
%
% End of shk4a
